#!/usr/bin/perl -w

# For Slimserver
# cover.jpg: 300x300
# thumb.jpg: 100x100

# For Windows Media Player
# Folder.jpg: 500x500
# AlbumArtSmall.jpg: copy of thumb.jpg (link)


use Image::Magick;
use File::Copy;
$img = Image::Magick->new;

if ($#ARGV < 0) 
{
	print "A folder name must be specified!\n";
	exit;
}

if (! -d $ARGV[0])
{
	print "The argument specified is not a directory!\n";
	exit;
}

$numFolders = 0;
$numFiles = 0;
$numImages = 0;
$recreate = 0;

ProcessFolder($ARGV[0]);

print "\n$numFiles files in $numFolders directories.\n";
print "$numImages images were processed\n";

exit;


sub ProcessFolder
{
	my ($folder) = $_[0];

	# Delete existing cover.jpg and thumb.jpg
	if( $recreate != 0 )
	{
		print "Deleting existing files\n";
		unlink("$folder/cover.jpg");
		unlink("$folder/thumb.jpg");
		unlink("$folder/Folder.jpg");
		unlink("$folder/AlbumArtSmall.jpg");
	}

	opendir DIR, $folder;
	my @contents = grep !/^\.\.?$/, readdir DIR;
	closedir DIR;

	foreach $listitem ( @contents )
	{

		if ( -d "$folder/$listitem" )
		{
			# Folder
			$numFolders++;
			ProcessFolder("$folder/$listitem");
		}
		else
		{
			$numFiles++;

			if($listitem =~ m/(cover.jpg|thumb.jpg|Folder.jpg|AlbumArtSmall.jpg)/)
			{
				next;
			}

			if ($listitem =~ m/.jpg$/i)
			{
				$numImages++;

				if(grep /(cover.jpg|thumb.jpg|Folder.jpg|AlbumArtSmall.jpg)/, @contents)
				{
					print "$listitem : Skipping.\n";
					next;		
				}

				# ($x, $y) = imgsize("$folder/$listitem");
				# print "$listitem [$x, $y]\n";
				print "$listitem : Generating images.\n";

				$img->Read("$folder/$listitem");
				$img->Resize(geometry=>'500x500', filter=>'Cubic');
				$img->Set(quality=>80);
				$img->UnsharpMask(radius=>0.5, sigma=>0.5, amount=>0.6, threshold=>0.05);
				$img->Write("$folder/Folder.jpg");
				@$img = ();

				$img->Read("$folder/$listitem");
				$img->Resize(geometry=>'300x300', filter=>'Cubic');
				$img->Set(quality=>80);
				$img->UnsharpMask(radius=>0.5, sigma=>0.5, amount=>0.6, threshold=>0.05);
				$img->Write("$folder/cover.jpg");
				@$img = ();

				$img->Read("$folder/$listitem");
				$img->Resize(geometry=>'100x100', filter=>'Cubic');
				$img->Set(quality=>80);
				$img->UnsharpMask(radius=>0.5, sigma=>0.5, amount=>0.6, threshold=>0.05);
				$img->Write("$folder/thumb.jpg");
				@$img = ();

				copy("$folder/thumb.jpg", "$folder/AlbumArtSmall.jpg");
			}
		}	
	}	
}
